@@ -102,7 +102,9 @@ class Saladier(object):
             req.remove_conditional_headers()
         resp = req.get_response(self.application)
         status = resp.status[0]
-        if resp.content_type and resp.content_type.startswith('text/html') and status in '245':
+        notheme = resp.headers.get('x-salade') == 'none'
+        if not notheme and resp.content_type and \
+           resp.content_type.startswith('text/html') and status in '245':
             # in case app change it
             if 'HTTP_HOST' in req.environ:
                 del req.environ['HTTP_HOST']
