@@ -7,7 +7,9 @@ dirname = os.path.dirname(__file__)
 def application(environ, start_response):
     req = Request(environ)
     resp = Response()
-    filename = os.path.join(dirname, req.path_info[1:])
+    filename = os.path.join(dirname, req.path_info.split('/')[-1])
+    if not os.path.isfile(filename):
+        filename = os.path.join(dirname, 'test.html')
     dummy, ext = os.path.splitext(filename)
     if ext in ('.html',):
         resp.content_type = 'text/html; charset=utf-8'
