@@ -18,11 +18,12 @@ class SimpleSalade(Salade):
         self.standard_rules()
         self.theme('#content').empty()
         self.theme('#content').append(self.content('body > *'))
-        if 'REMOTE_USER' not in self.request.environ:
-            self.request.environ['REMOTE_USER'] = 'Anonymous'
+        if not self.request.remote_user:
+            self.request.remote_user = 'Anonymous'
         resp = self.get('/user.html')
         self.theme('#content').prepend(resp.doc('#user_infos'))
         self.rewrite_links()
+        resp = self.get('http://www.google.com')
         return self.theme
 
 class Tests(unittest.TestCase):
